@@ -7,15 +7,15 @@ test_env.unload_luarocks()
 
 local extra_rocks = {
    "/abelhas-1.1-1.rockspec",
-   "/lpeg-0.12-1.rockspec"
+   "/lpeg-${LPEG}.rockspec"
 }
 
-describe("LuaRocks new_version tests #integration", function()
+describe("luarocks new_version #integration", function()
 
    setup(function()
       test_env.setup_specs(extra_rocks)
    end)
-   
+
    describe("basic tests", function()
       it("with no flags/arguments", function()
          finally(function()
@@ -26,7 +26,7 @@ describe("LuaRocks new_version tests #integration", function()
          assert(lfs.chdir("empty"))
          assert.is_false(run.luarocks_bool("new_version"))
       end)
-      
+
       it("with invalid", function()
          assert.is_false(run.luarocks_bool("new_version invalid"))
       end)
@@ -41,8 +41,8 @@ describe("LuaRocks new_version tests #integration", function()
 
    describe("more complex tests", function()
       it("of luacov", function()
-         assert.is_true(run.luarocks_bool("download --rockspec luacov 0.11.0"))
-         assert.is_true(run.luarocks_bool("new_version luacov-0.11.0-1.rockspec 0.2"))
+         assert.is_true(run.luarocks_bool("download --rockspec luacov ${LUACOV_V}"))
+         assert.is_true(run.luarocks_bool("new_version luacov-${LUACOV}.rockspec 0.2"))
          assert.is.truthy(lfs.attributes("luacov-0.2-1.rockspec"))
          test_env.remove_files(lfs.currentdir(), "luacov%-")
       end)
@@ -53,17 +53,17 @@ describe("LuaRocks new_version tests #integration", function()
          assert.is.truthy(lfs.attributes("abelhas-1.2-1.rockspec"))
          test_env.remove_files(lfs.currentdir(), "abelhas%-")
       end)
-      
+
       it("of luacov with tag", function()
-         assert.is_true(run.luarocks_bool("download --rockspec luacov 0.11.0"))
-         assert.is_true(run.luarocks_bool("new_version luacov-0.11.0-1.rockspec --tag v0.3"))
+         assert.is_true(run.luarocks_bool("download --rockspec luacov ${LUACOV_V}"))
+         assert.is_true(run.luarocks_bool("new_version luacov-${LUACOV}.rockspec --tag v0.3"))
          assert.is.truthy(lfs.attributes("luacov-0.3-1.rockspec"))
          test_env.remove_files(lfs.currentdir(), "luacov%-")
       end)
 
       it("updating md5", function()
-         assert.is_true(run.luarocks_bool("download --rockspec lpeg 0.12"))
-         assert.is_true(run.luarocks_bool("new_version lpeg-0.12-1.rockspec 0.2 https://luarocks.org/manifests/gvvaughan/lpeg-1.0.0-1.rockspec"))
+         assert.is_true(run.luarocks_bool("download --rockspec lpeg ${LPEG_V}"))
+         assert.is_true(run.luarocks_bool("new_version lpeg-${LPEG}.rockspec 0.2 https://luarocks.org/manifests/gvvaughan/lpeg-1.0.0-1.rockspec"))
          test_env.remove_files(lfs.currentdir(), "lpeg%-")
       end)
    end)
